@@ -37,7 +37,7 @@ use log::{debug, error, info, warn};
 use rayon::prelude::*;
 use std::fmt;
 use std::fs::{copy, File, Metadata};
-use std::io::{stdin, stdout, BufWriter, Read, Write};
+use std::io::{stdin, stdout, BufWriter, Cursor, Read, Write};
 use std::path::{Path, PathBuf};
 use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::Arc;
@@ -131,6 +131,10 @@ pub struct Options {
     ///
     /// Default: `false`
     pub fix_errors: bool,
+    /// Don't actually run any optimizations, just parse the PNG file.
+    ///
+    /// Default: `false`
+    pub check: bool,
     /// Don't actually write any output, just calculate the best results.
     ///
     /// Default: `false`
@@ -299,6 +303,7 @@ impl Default for Options {
 
         Options {
             backup: false,
+            check: false,
             pretend: false,
             fix_errors: false,
             force: false,
@@ -363,6 +368,11 @@ pub fn optimize(input: &InFile, output: &OutFile, opts: &Options) -> PngResult<(
 
     let mut png = PngData::from_slice(&in_data, opts.fix_errors)?;
 
+    if opts.check {
+        info!("Running in check mode, not optimizing");
+        return Ok(());
+    }
+
     // Run the optimizer on the decoded PNG.
     let mut optimized_output = optimize_png(&mut png, &in_data, opts, deadline)?;
 
@@ -608,7 +618,7 @@ fn optimize_png(
                     &deadline,
                 ),
                 #[cfg(feature = "zopfli")]
-                Deflaters::Zopfli => deflate::zopfli_deflate(filtered),
+                Deflaters::Zopfli { iterations } => deflate::zopfli_deflate(filtered, iterations),
                 #[cfg(feature = "libdeflater")]
                 Deflaters::Libdeflater => deflate::libdeflater_deflate(filtered, &best_size),
             };
@@ -700,8 +710,8 @@ fn optimize_png(
     }
 
     let (old_png, new_png) = rayon::join(
-        || image::load_from_memory_with_format(original_data, ImageFormat::Png),
-        || image::load_from_memory_with_format(&output, ImageFormat::Png),
+        || load_png_image_from_memory(original_data),
+        || load_png_image_from_memory(&output),
     );
 
     if let Ok(new_png) = new_png {
@@ -1066,6 +1076,14 @@ fn copy_times(input_path_meta: &Metadata, out_path: &Path) -> PngResult<()> {
     })
 }
 
+/// Loads a PNG image from memory to a [DynamicImage]
+fn load_png_image_from_memory(png_data: &[u8]) -> Result<DynamicImage, image::ImageError> {
+    let mut reader = image::io::Reader::new(Cursor::new(png_data));
+    reader.set_format(ImageFormat::Png);
+    reader.no_limits();
+    reader.decode()
+}
+
 /// Compares images pixel by pixel for equivalent content
 fn images_equal(old_png: &DynamicImage, new_png: &DynamicImage) -> bool {
     let a = old_png.pixels().filter(|x| {
