@@ -13,7 +13,7 @@
 #![warn(clippy::range_plus_one)]
 #![allow(clippy::cognitive_complexity)]
 
-use clap::{App, AppSettings, Arg, ArgMatches};
+use clap::{AppSettings, Arg, ArgMatches, Command};
 use indexmap::IndexSet;
 use log::{error, warn};
 use oxipng::AlphaOptim;
@@ -22,26 +22,26 @@ use oxipng::Headers;
 use oxipng::Options;
 use oxipng::{InFile, OutFile};
 use std::fs::DirBuilder;
+use std::num::NonZeroU8;
 use std::path::PathBuf;
 use std::process::exit;
 use std::time::Duration;
 
 fn main() {
-    let matches = App::new("oxipng")
+    let matches = Command::new("oxipng")
         .version(env!("CARGO_PKG_VERSION"))
         .author("Joshua Holmer <jholmer.in@gmail.com>")
         .about("Losslessly improves compression of PNG files")
         .setting(AppSettings::DeriveDisplayOrder)
-        .setting(AppSettings::UnifiedHelpMessage)
-        .arg(Arg::with_name("files")
+        .arg(Arg::new("files")
             .help("File(s) to compress (use \"-\" for stdin)")
             .index(1)
-            .multiple(true)
-            .use_delimiter(false)
+            .multiple_values(true)
+            .use_value_delimiter(false)
             .required(true))
-        .arg(Arg::with_name("optimization")
+        .arg(Arg::new("optimization")
             .help("Optimization level - Default: 2")
-            .short("o")
+            .short('o')
             .long("opt")
             .takes_value(true)
             .value_name("level")
@@ -53,115 +53,119 @@ fn main() {
             .possible_value("5")
             .possible_value("6")
             .possible_value("max"))
-        .arg(Arg::with_name("backup")
+        .arg(Arg::new("backup")
             .help("Back up modified files")
-            .short("b")
+            .short('b')
             .long("backup"))
-        .arg(Arg::with_name("recursive")
+        .arg(Arg::new("recursive")
             .help("Recurse into subdirectories")
-            .short("r")
+            .short('r')
             .long("recursive"))
-        .arg(Arg::with_name("output_dir")
+        .arg(Arg::new("output_dir")
             .help("Write output file(s) to <directory>")
             .long("dir")
             .takes_value(true)
             .value_name("directory")
             .conflicts_with("output_file")
             .conflicts_with("stdout"))
-        .arg(Arg::with_name("output_file")
+        .arg(Arg::new("output_file")
             .help("Write output file to <file>")
             .long("out")
             .takes_value(true)
             .value_name("file")
             .conflicts_with("output_dir")
             .conflicts_with("stdout"))
-        .arg(Arg::with_name("stdout")
+        .arg(Arg::new("stdout")
             .help("Write output to stdout")
             .long("stdout")
             .conflicts_with("output_dir")
             .conflicts_with("output_file"))
-        .arg(Arg::with_name("preserve")
+        .arg(Arg::new("preserve")
             .help("Preserve file attributes if possible")
-            .short("p")
+            .short('p')
             .long("preserve"))
-        .arg(Arg::with_name("pretend")
+        .arg(Arg::new("check")
+            .help("Do not run any optimization passes")
+            .short('c')
+            .long("check"))
+        .arg(Arg::new("pretend")
             .help("Do not write any files, only calculate compression gains")
-            .short("P")
+            .short('P')
             .long("pretend"))
-        .arg(Arg::with_name("strip-safe")
+        .arg(Arg::new("strip-safe")
             .help("Strip safely-removable metadata objects")
-            .short("s")
+            .short('s')
             .conflicts_with("strip"))
-        .arg(Arg::with_name("strip")
+        .arg(Arg::new("strip")
             .help("Strip metadata objects ['safe', 'all', or comma-separated list]")
             .long("strip")
             .takes_value(true)
             .value_name("mode")
             .conflicts_with("strip-safe"))
-        .arg(Arg::with_name("keep")
+        .arg(Arg::new("keep")
             .help("Strip all optional metadata except objects in the comma-separated list")
             .long("keep")
             .takes_value(true)
             .value_name("list")
             .conflicts_with("strip")
             .conflicts_with("strip-safe"))
-        .arg(Arg::with_name("alpha")
+        .arg(Arg::new("alpha")
             .help("Perform additional alpha optimizations")
-            .short("a")
+            .short('a')
             .long("alpha"))
-        .arg(Arg::with_name("interlace")
+        .arg(Arg::new("interlace")
             .help("PNG interlace type")
-            .short("i")
+            .short('i')
             .long("interlace")
             .takes_value(true)
             .value_name("0/1")
             .possible_value("0")
             .possible_value("1"))
-        .arg(Arg::with_name("verbose")
+        .arg(Arg::new("verbose")
             .help("Run in verbose mode")
-            .short("v")
+            .short('v')
             .long("verbose")
             .conflicts_with("quiet"))
-        .arg(Arg::with_name("quiet")
+        .arg(Arg::new("quiet")
             .help("Run in quiet mode")
-            .short("q")
+            .short('q')
             .long("quiet")
             .conflicts_with("verbose"))
-        .arg(Arg::with_name("filters")
+        .arg(Arg::new("filters")
             .help("PNG delta filters (0-5) - Default: 0,5")
-            .short("f")
+            .short('f')
             .long("filters")
             .takes_value(true)
             .validator(|x| {
-                match parse_numeric_range_opts(&x, 0, 5) {
+                match parse_numeric_range_opts(x, 0, 5) {
                     Ok(_) => Ok(()),
                     Err(_) => Err("Invalid option for filters".to_owned()),
                 }
             }))
-        .arg(Arg::with_name("compression")
+        .arg(Arg::new("compression")
             .help("zlib compression levels (1-9) - Default: 9")
             .long("zc")
             .takes_value(true)
             .value_name("levels")
             .validator(|x| {
-                match parse_numeric_range_opts(&x, 1, 9) {
+                match parse_numeric_range_opts(x, 1, 9) {
                     Ok(_) => Ok(()),
                     Err(_) => Err("Invalid option for compression".to_owned()),
                 }
             })
         .conflicts_with_all(&["zopfli", "libdeflater"]))
-        .arg(Arg::with_name("strategies")
+        .arg(Arg::new("strategies")
             .help("zlib compression strategies (0-3) - Default: 0-3")
             .long("zs")
             .takes_value(true)
             .validator(|x| {
-                match parse_numeric_range_opts(&x, 0, 3) {
+                match parse_numeric_range_opts(x, 0, 3) {
                     Ok(_) => Ok(()),
                     Err(_) => Err("Invalid option for strategies".to_owned()),
                 }
             })
             .conflicts_with_all(&["zopfli", "libdeflater"]))
-        .arg(Arg::with_name("window")
+        .arg(Arg::new("window")
             .help("zlib window size - Default: 32k")
             .long("zw")
             .takes_value(true)
@@ -175,49 +179,49 @@ fn main() {
             .possible_value("16k")
             .possible_value("32k")
             .conflicts_with_all(&["zopfli", "libdeflater"]))
-        .arg(Arg::with_name("no-bit-reduction")
+        .arg(Arg::new("no-bit-reduction")
             .help("No bit depth reduction")
             .long("nb"))
-        .arg(Arg::with_name("no-color-reduction")
+        .arg(Arg::new("no-color-reduction")
             .help("No color type reduction")
             .long("nc"))
-        .arg(Arg::with_name("no-palette-reduction")
+        .arg(Arg::new("no-palette-reduction")
             .help("No palette reduction")
             .long("np"))
-        .arg(Arg::with_name("no-grayscale-reduction")
+        .arg(Arg::new("no-grayscale-reduction")
             .help("No grayscale reduction")
             .long("ng"))
-        .arg(Arg::with_name("no-reductions")
+        .arg(Arg::new("no-reductions")
             .help("No reductions")
             .long("nx"))
-        .arg(Arg::with_name("no-recoding")
+        .arg(Arg::new("no-recoding")
             .help("No IDAT recoding unless necessary")
             .long("nz"))
-        .arg(Arg::with_name("fix")
+        .arg(Arg::new("fix")
             .help("Enable error recovery")
             .long("fix"))
-        .arg(Arg::with_name("force")
+        .arg(Arg::new("force")
             .help("Write the output even if it is larger than the input")
             .long("force"))
-        .arg(Arg::with_name("zopfli")
+        .arg(Arg::new("zopfli")
             .help("Use the slower but better compressing Zopfli algorithm, overrides zlib-specific options")
-            .short("Z")
+            .short('Z')
             .long("zopfli")
             .conflicts_with("libdeflater"))
-        .arg(Arg::with_name("libdeflater")
+        .arg(Arg::new("libdeflater")
             .help("Use an alternative Libdeflater algorithm, overrides zlib-specific options")
-            .short("D")
+            .short('D')
             .long("libdeflater")
             .conflicts_with("zopfli"))
-        .arg(Arg::with_name("timeout")
+        .arg(Arg::new("timeout")
             .help("Maximum amount of time, in seconds, to spend on optimizations")
             .takes_value(true)
             .value_name("secs")
             .long("timeout"))
-        .arg(Arg::with_name("threads")
+        .arg(Arg::new("threads")
             .help("Set number of threads to use - default 1.5x CPU cores")
             .long("threads")
-            .short("t")
+            .short('t')
             .takes_value(true)
             .value_name("num")
             .validator(|x| {
@@ -416,6 +420,10 @@ fn parse_opts_into_struct(
         opts.fix_errors = true;
     }
 
+    if matches.is_present("check") {
+        opts.check = true;
+    }
+
     if matches.is_present("pretend") {
         opts.pretend = true;
     }
@@ -488,7 +496,9 @@ fn parse_opts_into_struct(
     }
 
     if matches.is_present("zopfli") {
-        opts.deflate = Deflaters::Zopfli;
+        opts.deflate = Deflaters::Zopfli {
+            iterations: NonZeroU8::new(15).unwrap(),
+        };
     } else if matches.is_present("libdeflater") {
         opts.deflate = Deflaters::Libdeflater;
     } else if let Deflaters::Zlib {
